@@ -10,7 +10,7 @@ from struct import pack # for network byte order
 # third party
 from mongrel2 import handler, request
 
-__version__ = '0.1.7'
+__version__ = '0.1.8'
 
 logger = logging.getLogger(__name__)
 
@@ -163,13 +163,11 @@ class Connection(handler.Connection):
         self.aborted = {}
 
     def recv(self):
-        """
-        this wraps frame handling to make it a little easier to deal with
-        """
+        """this wraps frame handling to make it a little easier to deal with"""
         ws_req = None
 
         while True:
-
+            logger.debug('WAITING FOR CONNECTION')
             m2_req = super(Connection, self).recv()
             logger.info('{} RECEIVED'.format(m2_req.conn_id))
 
@@ -177,13 +175,16 @@ class Connection(handler.Connection):
                 ws_req = self.request_class(m2_req)
 
                 if ws_req.is_handshake():
+                    logger.debug('{} HANDSHAKE'.format(ws_req.conn_id))
                     ws_req.needs_response = True
 
                 elif ws_req.is_disconnect():
                     # drop these through so they can be handled
+                    logger.debug('{} DISCONNECT'.format(ws_req.conn_id))
                     ws_req.needs_response = False
 
                 elif not ws_req.is_websocket():
+                    logger.debug('{} WEBSOCKET'.format(ws_req.conn_id))
                     ws_req.needs_response = True
 
                 elif ws_req.is_close():
@@ -197,17 +198,16 @@ class Connection(handler.Connection):
                     else:
                         # we still want to return this request to give the controller a chance to do other cleanup
                         # even though we have done everything we needed to do to close the connection already
-                        self.reply_to_close(ws_req)
+                        self.reply_close(ws_req)
                         ws_req.needs_response = False
 
                 else:
-
                     if self.is_closed(ws_req):
                         logger.info('{} CLOSED, ignoring opcode {}'.format(ws_req.conn_id, ws_req.opcode))
                         continue
 
                     elif ws_req.is_ping():
-                        self.reply_to_ping(ws_req)
+                        self.reply_pong(ws_req)
                         continue
 
                     elif ws_req.is_pong():
@@ -278,15 +278,15 @@ class Connection(handler.Connection):
     def reply_non_websocket(self, req):
         """handle any non websocket requests, normally, you'll want to just fail it
         but sometimes it is handy to be able to override this in a child class to
-        handle custom cases (specifically for us, a pingdom check"""
+        handle custom cases (specifically for us, a pingdom check)"""
         return self.reply_invalid(req)
 
-    def reply_to_ping(self, req):
+    def reply_pong(self, req):
         """reply to a ping request with a pong request"""
         logger.info('{} PING -> replying PONG'.format(req.conn_id))
         self.reply_websocket(req, req.body, OP_PONG)
 
-    def reply_to_close(self, req):
+    def reply_close(self, req):
         """reply to a close request"""
         logger.info('{} CLIENT CLOSED'.format(req.conn_id))
         # the client has closed on us, we need to send down OP_CLOSE to complete the handshake
@@ -294,27 +294,9 @@ class Connection(handler.Connection):
 
         self.close(req)
 
-    def reply_to_websocket(self, req, to_conn_id, body, opcode):
-        """
-        send a reply to a connection
-
-        this is different than reply_websocket() because it allows you to send the
-        reply to a different websocket than the one that originally made the request
-        """
-        orig_conn_id = req.conn_id
-        req.conn_id = to_conn_id
-        logger.debug("{} -> {} reply_to websocket {}, OPCODE: {}".format(orig_conn_id, to_conn_id, body, opcode))
-        self.reply_websocket(req, body, opcode)
-        req.conn_id = orig_conn_id
-
-    def forward_websocket(self, req, to_conn_id):
-        """
-        this just takes the websocket request and sends it to another connection
-
-        this is handy for communication between 2 websockets, say if you were writing
-        a chat application or something ;)
-        """
-        self.reply_to_websocket(req, to_conn_id, req.body, req.opcode)
+    def reply_websocket(self, req, *args, **kwargs):
+        if not getattr(req, 'needs_response', True): return
+        return super(Connection, self).reply_websocket(req, *args, **kwargs)
 
     def abort(self, req, e=None):
         """
